#

##

##

###

##

    	mottoes
    		# chorus, multichorus
    			# chants

    		# inspiration
    		# essence
    		# physics
    		# climate
    		# preferences

    	summary

    		These are things that require an active vote to change.

    	objectives

    		{
    			"petitions": {
    				"voting": {
    					">= fraction necessary": "1/2"
    				},
    				"fees": {
    					"send escrow": "",
    					"receive escrow": ""
    				}
    			},

    		}

    		fee changes
    			[ ] fee changes

    	possibilites

    		[ ] voter consensus mechanism changes